; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

;------------------------
[Command]
name = "dfdf_a"
command = ~D, DF, F, D, DF, F, b
time = 30


[Command]
name = "dfdf_x"
command = ~D, DB, B, D, DB, B, y
time = 30

[Command]
name = "spiralcannon"
command = ~D, B, D, B, b
time = 25


;-| Special Motions |------------------------------------------------------
[Command]
name = "df_a"
command = ~D, DF, F, a

[Command]
name = "df_b"
command = ~D, DF, F, b

[Command]
name = "bf_x"
command = ~B, F, x

[Command]
name = "bf_y"
command = ~B, F, y

[Command]
name = "abf_x"
command = ~B, F, x

[Command]
name = "abf_y"
command = ~B, F, y

[Command]
name = "dfx"
command = D, DF, F, x

[Command]
name = "dfy"
command = D, DF, F, y
time = 40

[Command]
name = "dfyyy"
command = D, DF, F, y, y
time = 75

;--------------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~50$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~50$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~50$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~50$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~50$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~50$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargebackfwd_c"
command = ~60$B, F, c
time = 10

[Command]
name = "chargebackfwd_x"
command = ~60$B, F, x
time = 10

[Command]
name = "chargebackfwd_y"
command = ~60$B, F, y
time = 10

[Command]
name = "chargebackfwd_z"
command = ~60$B, F, z
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "hold_x"
command = /$x
time = 1

[Command]
name = "hold_y"
command = /$y
time = 1

[Command]
name = "hold_z"
command = /$z
time = 1

[Command]
name = "hold_a"
command = /$a
time = 1

[Command]
name = "hold_b"
command = /$b
time = 1

[Command]
name = "hold_c"
command = /$c
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;===========================================================================
[State -1]
type = ChangeState
value = 1350
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = "abf_x"
trigger2 = movecontact = 1
trigger2 = stateno = 601
trigger3 = movecontact = 1
trigger3 = stateno = 600
trigger4 = movecontact = 1
trigger4 = stateno = 603
trigger5 = movecontact = 1
trigger5 = stateno = 602
trigger6 = movecontact = 1
trigger6 = stateno = 606
trigger7 = movecontact = 1
trigger7 = stateno = 605
trigger8 = movecontact = 1
trigger8 = stateno = 604
trigger9 = movecontact = 1
trigger9 = stateno = 607
trigger10 = movecontact = 1
trigger10 = stateno = 608
[State -1]
type = ChangeState
value = 1350
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = "abf_y"
trigger2 = movecontact = 1
trigger2 = stateno = 601
trigger3 = movecontact = 1
trigger3 = stateno = 600
trigger4 = movecontact = 1
trigger4 = stateno = 603
trigger5 = movecontact = 1
trigger5 = stateno = 602
trigger6 = movecontact = 1
trigger6 = stateno = 606
trigger7 = movecontact = 1
trigger7 = stateno = 605
trigger8 = movecontact = 1
trigger8 = stateno = 604
trigger9 = movecontact = 1
trigger9 = stateno = 607
trigger10 = movecontact = 1
trigger10 = stateno = 608  

;---------------------------------------------------------------------------
; Spiral Cannon
[State -1]
type = ChangeState
value = 1520
triggerall = power >= 1000
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "spiralcannon"
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1320
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "dfyyy"
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 215
trigger4 = movecontact = 1
trigger5 = stateno = 220
trigger5 = movecontact = 1
trigger6 = stateno = 225
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 255
trigger9 = movecontact = 1
trigger10 = stateno = 300
trigger10 = movecontact = 1
trigger11 = stateno = 310
trigger11 = movecontact = 1
trigger12 = stateno = 320
trigger12 = movecontact = 1
trigger13 = stateno = 330
trigger13 = movecontact = 1
trigger14 = stateno = 340
trigger14 = movecontact = 1
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1310
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "dfy"
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1301
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "dfx"
;---------------------------------------------------------------------------
; CHARGE
[State -1]
type = ChangeState
value = 735
triggerall = statetype = S
triggerall = Power < 3000
triggerall = ctrl = 1
trigger1 = command = "x"
trigger1 = command = "b"
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1100
triggerall = command = "dfdf_x"
triggerall = power >= 2000 
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1000
triggerall = command = "dfdf_a"
triggerall = power >= 1000 
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 980
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "bf_x"
[State -1]
type = ChangeState
value = 980
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "bf_y"
;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 950
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "df_a"
[State -1]
type = ChangeState
value = 950
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "df_b"
;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
[State -1]
type = ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_b";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand X
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2bodydist X > 5
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = animelem >= 4
trigger2 = stateno = 200
trigger3 = MoveContact = 1
trigger3 = stateno = 200
trigger4 = MoveContact = 1
trigger4 = stateno = 400

;---------------------------------------------------------------------------
;Stand Y
[State -1]
type = ChangeState
value = 201
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2bodydist X > 8
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 205
trigger2 = movecontact = 1
trigger3 = stateno = 215
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Stand A
[State -1]
type = ChangeState
value = 204
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2bodydist X > 5
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = animelem >= 4
trigger2 = stateno = 200
trigger3 = MoveContact = 1
trigger3 = stateno = 200
trigger4 = MoveContact = 1
trigger4 = stateno = 400

;---------------------------------------------------------------------------
;Stand B
[State -1]
type = ChangeState
value = 205
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X > 5
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 207
trigger6 = MoveContact = 1
trigger6 = stateno = 400
trigger7 = MoveContact = 1
trigger7 = stateno = 401
trigger8 = MoveContact = 1
trigger8 = stateno = 404

;---------------------------------------------------------------------------
;Close Y
[State -1]
type = ChangeState
value = 207
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 10
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 204
trigger4 = MoveContact = 1
trigger4 = stateno = 400
trigger5 = MoveContact = 1
trigger5 = stateno = 404

;---------------------------------------------------------------------------
;Close B
[State -1]
type = ChangeState
value = 208
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 5
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Close A
[State -1]
type = ChangeState
value = 209
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 5
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Close X
[State -1]
type = ChangeState
value = 211
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 5
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch X
[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch Y
[State -1]
type = ChangeState
value = 401
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 404
trigger4 = movecontact = 1
trigger4 = stateno = 200
trigger5 = movecontact = 1
trigger5 = stateno = 204
trigger6 = movecontact = 1
trigger6 = stateno = 207

;---------------------------------------------------------------------------
;Crouch Z
[State -1]
type = ChangeState
value = 402
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 405
trigger6 = movecontact = 1
trigger6 = stateno = 200
trigger7 = movecontact = 1
trigger7 = stateno = 201
trigger8 = movecontact = 1
trigger8 = stateno = 204
trigger9 = movecontact = 1
trigger9 = stateno = 205
trigger10 = movecontact = 1
trigger10 = stateno = 207
trigger11 = movecontact = 1
trigger11 = stateno = 208

;---------------------------------------------------------------------------
;Aerial Rave Jump
[State -1]
type = ChangeState
value = 40
triggerall = command = "holdup"
trigger1 = movecontact = 1
trigger1 = stateno = 402

;---------------------------------------------------------------------------
;Crouch A
[State -1]
type = ChangeState
value = 404
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 200
trigger4 = movecontact = 1
trigger4 = stateno = 204

;---------------------------------------------------------------------------
;Crouch B
[State -1]
type = ChangeState
value = 405
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 200
trigger6 = movecontact = 1
trigger6 = stateno = 201
trigger7 = movecontact = 1
trigger7 = stateno = 204
trigger8 = movecontact = 1
trigger8 = stateno = 207
trigger9 = movecontact = 1
trigger9 = stateno = 208

;---------------------------------------------------------------------------
;Jump X
[State -1]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump Y
[State -1]
type = ChangeState
value = 601
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 604

;---------------------------------------------------------------------------
;Jump A
[State -1]
type = ChangeState
value = 604
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600

;---------------------------------------------------------------------------
;Jump Up B
[State -1]
type = ChangeState
value = 608
triggerall = vel X = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607

;---------------------------------------------------------------------------
;Jump B
[State -1]
type = ChangeState
value = 605
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 195
triggerall = command = "s"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
